Tla�tko vloit obr�ek

Tlačitko vložiť obrázok | Obsah

Tlačitko vložiť obrázok otvorý následujúce okno.
Iba vložte URL obrázku, ktorý chcete pridať a zadajte jeho popis, ten bude zobrazovaný ako alternatívny popisok obrázku.
Popis položiek:

URL obrázku | URL/cesta k obrázku.
Popis obrázku | Alternatívny popis toho, co je na obrázku.
Rozmery | šírka/výška obrázku.
Zarovnávanie | Zarovnávanie obrázku, vhodné pre obtekanie obrázku textom.
Ramček | Hrúbka ramčeku.
Vertikálny okraj | Vertikálny okraj, vhodné pre zalomenie textu okolo obrázku.
Horizontálny okraj | Horizontány okraj, vhodné pre zalomenie textu okolo obrázku.

Choď na: Obsah | Nahor